@@ -17,13 +17,23 @@ class HasActivitiesMixin(object):
     def _get_activity_join_by_entity_id_filter(self):
         Activity = Activator.get_activity()
         id_key = self.__class__.id.property.key
-        return Activity.data[id_key].astext.cast(BigInteger) == getattr(self, id_key)
+        id_value = getattr(self, id_key)
+        return (
+            (Activity.old_data[id_key].astext.cast(BigInteger) == id_value) | \
+            (Activity.changed_data[id_key].astext.cast(BigInteger) == id_value)
+        )
+
+    def _get_activity_join_filter(self):
+        Activity = Activator.get_activity()
+        return (
+            (Activity.table_name == self.__tablename__) & \
+            (self._get_activity_join_by_entity_id_filter())
+        )
 
     @property
     def __activities__(self):
         Activity = Activator.get_activity()
-        query_filter = (Activity.table_name == self.__tablename__) & \
-                       (self._get_activity_join_by_entity_id_filter())
+        query_filter = self._get_activity_join_filter()
         return InstrumentedList(Activity.query.filter(query_filter) \
                                               .order_by(Activity.dateCreated) \
                                               .order_by(Activity.id) \
@@ -32,24 +42,23 @@ class HasActivitiesMixin(object):
     @property
     def __deleteActivity__(self):
         Activity = Activator.get_activity()
-        query_filter = (Activity.table_name == self.__tablename__) & \
-                       (self._get_activity_join_by_entity_id_filter()) & \
-                       (Activity.verb == 'delete')
+        query_filter = (
+            (self._get_activity_join_filter()) & \
+            (Activity.verb == 'delete')
+        )
         return Activity.query.filter(query_filter).one()
 
     @property
     def __insertActivity__(self):
         Activity = Activator.get_activity()
-        query_filter = (Activity.table_name == self.__tablename__) & \
-                       (self._get_activity_join_by_entity_id_filter()) & \
+        query_filter = (self._get_activity_join_filter()) & \
                        (Activity.verb == 'insert')
         return Activity.query.filter(query_filter).one()
 
     @property
     def __lastActivity__(self):
         Activity = Activator.get_activity()
-        query_filter = (Activity.table_name == self.__tablename__) & \
-                       (self._get_activity_join_by_entity_id_filter()) & \
+        query_filter = (self._get_activity_join_filter()) & \
                        (Activity.verb == 'update')
         return Activity.query.filter(query_filter) \
                              .order_by(desc(Activity.dateCreated)) \
